@@ -18,7 +18,11 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#define PREFIX "/usr"
+#endif
 
 #include <kgenericfactory.h>
 #include <kpushbutton.h>
@@ -53,7 +57,7 @@ console::console(TQWidget *parent, const TQStrList &run, const char *name, const
 
 	if ((pipe_prefix = popen(prefixcommand.c_str(), "r")) == NULL)
 	{
-		m_kdePrefix = "/usr";
+		m_kdePrefix = PREFIX;
 	}
 	else {
 		fgets(prefix_result, 2048, pipe_prefix);
