@@ -60,7 +60,7 @@ kdpkg::kdpkg( const TQString &url, TQWidget *parent, const char *name, const TQS
 
 
 	// show files
-	this->shell->setCommand("dpkg -c "+url);
+	this->shell->setCommand("dpkg -c "+path);
 	this->shell->start(true);
 	TQStringList files = TQStringList::split( "\n", this->shell->getBuffer().stripWhiteSpace() );
 	TQString tmp;
